@@ -13,6 +13,9 @@ import numpy as np
 import tensorflow as tf
 from sklearn.model_selection import ParameterGrid
 from sklearn.model_selection import ParameterSampler
+from tensorflow.keras.models import Model
+
+from tensorcross._types import ResultsDict
 
 
 logger = tf.get_logger()
@@ -32,14 +35,14 @@ class BaseSearch(metaclass=ABCMeta):
     @abstractmethod
     def __init__(
         self,
-        model_fn: Callable[..., tf.keras.models.Model],
+        model_fn: Callable[..., Model],
         verbose: int = 0,
         **kwargs: Any,
     ) -> None:
         self.model_fn = model_fn
         self.verbose = verbose
         self.model_fn_kwargs = kwargs
-        self.results_ = {
+        self.results_: ResultsDict = {
             "best_score": -np.inf,
             "best_params": {},
             "val_scores": [],
@@ -65,7 +68,7 @@ class BaseSearch(metaclass=ABCMeta):
             kwargs (Any): Keyword arguments for the fit method of the
                 tf.keras.models.Model or tf.keras.models.Sequential model.
         """
-
+        maximize = True
         tensorboard_callback = None
         tensorboard_log_dir = ""
 
@@ -89,7 +92,7 @@ class BaseSearch(metaclass=ABCMeta):
             if tensorboard_callback:
                 if not os.path.exists(tensorboard_log_dir):
                     os.mkdir(tensorboard_log_dir)
-                new_log_dir = os.path.join(tensorboard_log_dir, f'model_{idx}')
+                new_log_dir = os.path.join(tensorboard_log_dir, f"model_{idx}")
                 os.mkdir(new_log_dir)
                 tensorboard_callback.log_dir = new_log_dir
 
@@ -98,12 +101,16 @@ class BaseSearch(metaclass=ABCMeta):
             if len(model.metrics) > 1:
                 val_score = model.evaluate(val_dataset, verbose=0)[-1]
             else:
+                maximize = False
                 val_score = model.evaluate(val_dataset, verbose=0)
             self.results_["val_scores"].append(val_score)
             self.results_["params"].append(grid_combination)
 
         logger.setLevel(tf_log_level)  # Issue 30
-        best_run_idx = np.argmax(self.results_["val_scores"])
+        if maximize:
+            best_run_idx = np.argmax(self.results_["val_scores"])
+        else:
+            best_run_idx = np.argmin(self.results_["val_scores"])
         self.results_["best_score"] = self.results_["val_scores"][best_run_idx]
         self.results_["best_params"] = self.results_["params"][best_run_idx]
 
@@ -154,7 +161,7 @@ class BaseSearch(metaclass=ABCMeta):
 class GridSearch(BaseSearch):
     def __init__(
         self,
-        model_fn: Callable[..., tf.keras.models.Model],
+        model_fn: Callable[..., Model],
         param_grid: Mapping[str, Iterable],
         verbose: int = 0,
         **kwargs: Any,
@@ -226,7 +233,7 @@ class GridSearch(BaseSearch):
 class RandomSearch(BaseSearch):
     def __init__(
         self,
-        model_fn: Callable[..., tf.keras.models.Model],
+        model_fn: Callable[..., Model],
         param_distributions: Dict[str, Callable],
         n_iter: int = 10,
         verbose: int = 0,
