@@ -13,7 +13,9 @@ import numpy as np
 import tensorflow as tf
 from sklearn.model_selection import ParameterGrid
 from sklearn.model_selection import ParameterSampler
+from tensorflow.keras.models import Model
 
+from tensorcross._types import ResultsDict
 from tensorcross.utils import dataset_split
 
 
@@ -36,7 +38,7 @@ class BaseSearchCV(metaclass=ABCMeta):
     @abstractmethod
     def __init__(
         self,
-        model_fn: Callable[..., tf.keras.models.Model],
+        model_fn: Callable[..., Model],
         n_folds: int = 3,
         verbose: int = 0,
         **kwargs: Any,
@@ -45,7 +47,7 @@ class BaseSearchCV(metaclass=ABCMeta):
         self.verbose = verbose
         self.n_folds = n_folds
         self.model_fn_kwargs = kwargs
-        self.results_ = {
+        self.results_: ResultsDict = {
             "best_score": -np.inf,
             "best_params": {},
             "val_scores": [],
@@ -67,6 +69,7 @@ class BaseSearchCV(metaclass=ABCMeta):
             kwargs (Any): Keyword arguments for the fit method of the
                 tf.keras.models.Model or tf.keras.models.Sequential model.
         """
+        maximize = True
         tensorboard_callback = None
         tensorboard_log_dir = ""
 
@@ -106,7 +109,7 @@ class BaseSearchCV(metaclass=ABCMeta):
                     if not os.path.exists(tensorboard_log_dir):
                         os.mkdir(tensorboard_log_dir)
                     new_log_dir = os.path.join(
-                        tensorboard_log_dir, f'model_{idx}_fold_{fold}'
+                        tensorboard_log_dir, f"model_{idx}_fold_{fold}"
                     )
                     os.mkdir(new_log_dir)
                     tensorboard_callback.log_dir = new_log_dir
@@ -116,6 +119,7 @@ class BaseSearchCV(metaclass=ABCMeta):
                 if len(model.metrics) > 1:
                     val_score = model.evaluate(val_dataset, verbose=0)[-1]
                 else:
+                    maximize = False
                     val_score = model.evaluate(val_dataset, verbose=0)
                 val_scores[fold] = val_score
 
@@ -125,7 +129,10 @@ class BaseSearchCV(metaclass=ABCMeta):
         logger.setLevel(tf_log_level)  # Issue 30
 
         mean_val_scores = np.mean(self.results_["val_scores"], axis=0)
-        best_run_idx = np.argmax(mean_val_scores)
+        if maximize:
+            best_run_idx = np.argmax(mean_val_scores)
+        else:
+            best_run_idx = np.argmin(mean_val_scores)
         self.results_["best_score"] = self.results_["val_scores"][best_run_idx]
         self.results_["best_params"] = self.results_["params"][best_run_idx]
 
@@ -176,7 +183,7 @@ class BaseSearchCV(metaclass=ABCMeta):
 class GridSearchCV(BaseSearchCV):
     def __init__(
         self,
-        model_fn: Callable[..., tf.keras.models.Model],
+        model_fn: Callable[..., Model],
         param_grid: Mapping[str, Iterable],
         n_folds: int = 3,
         verbose: int = 0,
@@ -241,7 +248,7 @@ class GridSearchCV(BaseSearchCV):
 class RandomSearchCV(BaseSearchCV):
     def __init__(
         self,
-        model_fn: Callable[..., tf.keras.models.Model],
+        model_fn: Callable[..., Model],
         param_distributions: Dict[str, Callable],
         n_iter: int = 10,
         n_folds: int = 3,
